@@ -1,7 +1,7 @@
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -223,14 +223,14 @@ nextword_main()
 static char *
 usage(char *s)
 {
-  j_printerr("nextword --- tty-based interactive grammar checker\n");
-  j_printerr("usage: %s prefix\n",s);
-  j_printerr("  -t      ... use category symbols instead of words (needs .term)\n");
-  j_printerr("  -s string ... specify short-pause model\n");
-  j_printerr("  -r      ... reverse order input\n");
-  j_printerr("  -v      ... verbose output\n");
+  fprintf(stderr, "nextword --- tty-based interactive grammar checker\n");
+  fprintf(stderr, "usage: %s prefix\n",s);
+  fprintf(stderr, "  -t      ... use category symbols instead of words (needs .term)\n");
+  fprintf(stderr, "  -s string ... specify short-pause model\n");
+  fprintf(stderr, "  -r      ... reverse order input\n");
+  fprintf(stderr, "  -v      ... verbose output\n");
 #ifndef HAVE_READLINE
-  j_printerr("(READLINE feature disabled)\n");
+  fprintf(stderr, "(READLINE feature disabled)\n");
 #endif
   exit(1);
 }
@@ -271,7 +271,7 @@ int main(int argc, char *argv[])
 	}
 	spname = argv[i];
       default:
-	j_printerr("no such option: %s\n",argv[i]);
+	fprintf(stderr, "no such option: %s\n",argv[i]);
 	usage(argv[0]);
       }
     } else {
@@ -335,9 +335,9 @@ int main(int argc, char *argv[])
   printf("----- \n");
 
 #ifdef HAVE_READLINE
-  j_printf("command completion is built-in\n----- \n");
+  printf("command completion is built-in\n----- \n");
 #else
-  j_printf("command completion is disabled\n----- \n");
+  printf("command completion is disabled\n----- \n");
 #endif
 
   /* initialize readline */
