@@ -1,14 +1,12 @@
 /**
  * @file   record.c
- * @author Akinobu Lee
- * @date   Tue Sep 06 14:13:54 2005
  * 
  * <JA>
- * @brief  ǧϲե¸롥
+ * @brief  ǧϲե¸. 
  *
- * Ϥ줿ǡ1Ĥĥե¸롥
- * ե̾ϿΥॹפ "YYYY.MMDD.HHMMSS.wav" Ȥʤ롥
- * ե Microsoft WAVE format, 16bit, PCM (̵) Ǥ롥
+ * Ϥ줿ǡ1Ĥĥե¸. 
+ * ե̾ϿΥॹפ "YYYY.MMDD.HHMMSS.wav" Ȥʤ. 
+ * ե Microsoft WAVE format, 16bit, PCM (̵) Ǥ. 
  *
  * ϿϤä˳ݤ줺ˡϤʿԤƥեľ
  * 񤭹ޤ롣ǽϰե˵Ͽ졢Ͽλʡ1ѥ
@@ -28,30 +26,32 @@
  * final filename descrived above.
  * </EN>
  * 
+ * @author Akinobu Lee
+ * @date   Tue Sep 06 14:13:54 2005
+ *
  * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
-#include <julius.h>
+#include "app.h"
 #include <time.h>
 
-#define TSTRLEN 18		///< String length of a time format
+static char *record_dirname = NULL;
 
-static char tstr[TSTRLEN];	///< Work area to hold time string
-static char recfilename[MAXLINELEN]; ///< Temporary file name for storing the incoming data
-static char finalfilename[MAXLINELEN]; ///< After recording is done, the file will be renames to this
-static FILE *fp = NULL;		///< File pointer of current file.
-static int totalnum;		///< Current number of recorded samples.
+static char rectmpfilename[MAXLINELEN];
+static char recordfilename[MAXLINELEN];
+static int recordlen;
+static FILE *recfile_fp;
 
 /** 
  * <JA>
- * ƥ֤١ե̾롥
+ * ƥ֤١ե̾. 
  * 
  * @param t [out] ̤ǼʸХåե
  * @param maxlen [in] @a t κĹ
@@ -77,8 +77,8 @@ timestring(char *t, int maxlen)
 
 /** 
  * <JA>
- * ١ե̾ºݤΥѥ̾롥ǥ쥯ȥѿ
- * record_dirname Ǥ餫ꤵƤ롥
+ * ١ե̾ºݤΥѥ̾. ǥ쥯ȥѿ
+ * record_dirname Ǥ餫ꤵƤ. 
  * 
  * @param buf [out] ̤Υѥ̾ǼХåեؤΥݥ
  * @param buflen [in] @a buf κĹ
@@ -94,10 +94,11 @@ timestring(char *t, int maxlen)
  * </EN>
  */
 static void
-make_record_filename(char *buf, int buflen, char *filename)
+make_record_filename(char *buf, int buflen, char *basename, char *dirname)
 {
-  if (record_dirname == NULL) {
-    j_error("no record directory specified??\n");
+  if (dirname == NULL) {
+    fprintf(stderr, "no record directory specified??\n");
+    return;
   }
   snprintf(buf, buflen,
 #if defined(_WIN32) && !defined(__CYGWIN32__)
@@ -105,12 +106,12 @@ make_record_filename(char *buf, int buflen, char *filename)
 #else
 	   "%s/%s.wav"
 #endif
-	   , record_dirname, filename);
+	   , dirname, basename);
 }
 
 /** 
  * <JA>
- * ե̾롥
+ * ե̾. 
  * 
  * @param buf [out] ̤Υե̾Ǽݥ
  * @param buflen [in] @a buf κĹ
@@ -123,18 +124,18 @@ make_record_filename(char *buf, int buflen, char *filename)
  * </EN>
  */
 static void
-make_tmp_filename(char *buf, int buflen)
+make_tmp_filename(char *buf, int buflen, char *dirname)
 {
 #if defined(_WIN32) && !defined(__CYGWIN32__)
-  snprintf(buf, buflen, "%s\\tmprecord.000", record_dirname);
+  snprintf(buf, buflen, "%s\\tmprecord.000", dirname);
 #else
-  snprintf(buf, buflen, "%s/tmprecord.%d", record_dirname, getpid());
+  snprintf(buf, buflen, "%s/tmprecord.%d", dirname, getpid());
 #endif
 }  
 
 /** 
  * <JA>
- * ϿΤ˰ե򥪡ץ󤹤롥
+ * ϿΤ˰ե򥪡ץ󤹤. 
  * 
  * </JA>
  * <EN>
@@ -142,24 +143,27 @@ make_tmp_filename(char *buf, int buflen)
  * 
  * </EN>
  */
-void
-record_sample_open()
+static void
+record_sample_open(Recog *recog, void *dummy)
 {
-  if (fp != NULL) {
-    j_error("Error: record_sample_open: re-opened before closed!\n");
-  }
-  make_tmp_filename(recfilename, MAXLINELEN);
-  if ((fp = wrwav_open(recfilename, smpFreq)) == NULL) {
-    perror("Error: record_sample_open");
-    j_error("failed to open \"%s\" (temporary record file)\n", recfilename);
+  if (recfile_fp != NULL) {
+    fprintf(stderr, "Error: record_sample_open: re-opened before closed!\n"); 
+    return;
   }
 
-  totalnum = 0;
+  make_tmp_filename(rectmpfilename, MAXLINELEN, record_dirname);
+  if ((recfile_fp = wrwav_open(rectmpfilename, recog->jconf->input.sfreq)) == NULL) {
+    perror("Error: record_sample_open");
+    fprintf(stderr, "failed to open \"%s\" (temporary record file)\n", rectmpfilename);
+    return;
+  }
+
+  recordlen = 0;
 }
 
 /** 
  * <JA>
- * ϲҤեɲõϿ롥
+ * ϲҤեɲõϿ. 
  * 
  * @param speech [in] ǡΥХåե
  * @param samplenum [in] ǡĹʥץ
@@ -171,30 +175,35 @@ record_sample_open()
  * @param samplenum [in] length of above in samples
  * </EN>
  */
-void
-record_sample_write(SP16 *speech, int samplenum)
+static void
+record_sample_write(Recog *recog, SP16 *speech, int samplenum, void *dummy)
 {
-  if (fp == NULL) {
-    j_error("Error: record_sample_write; file not opened yet, cannot write!\n");
+  static char tstr[20];
+
+  if (recfile_fp == NULL) {
+    fprintf(stderr, "Error: record_sample_write; file not opened yet, cannot write!\n");
+    return;
   }
 
-  if (wrwav_data(fp, speech, samplenum) == FALSE) {
+  if (wrwav_data(recfile_fp, speech, samplenum) == FALSE) {
     perror("Error: record_sample_write");
-    j_error("failed to write samples to \"%s\"\n", recfilename);
+    fprintf(stderr, "failed to write samples to \"%s\"\n", rectmpfilename);
+    return;
   }
 
   /* make timestamp of system time when an input begins */
   /* the current temporal recording file will be renamed to this time-stamp filename */
-  if (totalnum == 0) {		/* beginning of recording */
-    timestring(tstr, TSTRLEN);
+  if (recordlen == 0) {		/* beginning of recording */
+    timestring(tstr, 18);
   }
+  make_record_filename(recordfilename, MAXLINELEN, tstr, record_dirname);
   
-  totalnum += samplenum;
+  recordlen += samplenum;
 }
 
 /** 
  * <JA>
- * Ͽλ롥ϿѤΰե򥯥̾rename롣
+ * Ͽλ. ϿѤΰե򥯥̾rename롣
  * 
  * </JA>
  * <EN>
@@ -203,34 +212,67 @@ record_sample_write(SP16 *speech, int samplenum)
  * 
  * </EN>
  */
-void
-record_sample_close()
+static void
+record_sample_close(Recog *recog, void *dummy)
 {
-  if (fp == NULL) {
-    j_printerr("Warning: record_sample_close; file not opened yet!?\n");
+  if (recfile_fp == NULL) {
+    fprintf(stderr, "Warning: record_sample_close; file not opened yet!?\n");
     return;
   }
 
-  if (wrwav_close(fp) == FALSE) {
+  if (wrwav_close(recfile_fp) == FALSE) {
     perror("Error: record_sample_close");
   }
-  fp = NULL;
+  recfile_fp = NULL;
 
-  if (totalnum == 0) {
-    unlink(recfilename);
+  if (recordlen == 0) {
+    unlink(rectmpfilename);
     if (verbose_flag) {
-      j_printerr("No input, not recorded\n");
+      fprintf(stderr, "No input, not recorded\n");
     }
     return;
   }
 
   /* now rename the temporary file to time-stamp filename */
-  make_record_filename(finalfilename, MAXLINELEN, tstr);
-  if (rename(recfilename, finalfilename) < 0) {
+  if (rename(rectmpfilename, recordfilename) < 0) {
     perror("Error: record_sample_close");
-    j_error("failed to move %s to %s\n", recfilename, finalfilename);
+    fprintf(stderr, "failed to move %s to %s\n", rectmpfilename, recordfilename);
+    return;
   }
   if (verbose_flag) {
-    j_printerr("recorded to \"%s\" (%d bytes, %.2f sec.)\n", finalfilename, totalnum * sizeof(SP16), (float)totalnum / (float) smpFreq);
+    fprintf(stderr, "recorded to \"%s\" (%d bytes, %.2f sec.)\n", recordfilename, recordlen * sizeof(SP16), (float)recordlen / (float) recog->jconf->input.sfreq);
+  }
+}
+
+/************************************************************************/
+static boolean
+opt_record(Jconf *jconf, char *arg[], int argnum)
+{
+  record_dirname = strdup(arg[0]);
+#if !defined(_WIN32) || defined(__CYGWIN32__)
+  if (access(record_dirname, R_OK | W_OK | X_OK) == -1) {
+    perror("checkdir");
+    fprintf(stderr, "Error: cannot write to dir %s\n", record_dirname);
+    return FALSE;
+  }
+#endif
+  return TRUE;
+}
+void
+record_add_option()
+{
+  j_add_option("-record", 1, 1, "record input waveform to file in dir", opt_record);
+}
+
+/************************************************************************/
+void
+record_setup(Recog *recog, void *data)
+{
+  if (record_dirname) {
+    /* regist callbacks */
+    callback_add(recog, CALLBACK_EVENT_SPEECH_READY, record_sample_open, data);
+    callback_add_adin(recog, CALLBACK_ADIN_TRIGGERED, record_sample_write, data);
+    callback_add(recog, CALLBACK_EVENT_SPEECH_STOP, record_sample_close, data);
+    printf("Input speech data will be stored to = %s/\n", record_dirname);
   }
 }
