@@ -36,7 +36,7 @@
  * @author Akinobu Lee
  * @date   Fri Oct 12 23:14:13 2007
  *
- * $Revision: 1.2 $
+ * $Revision: 1.5 $
  * 
  */
 /*
@@ -135,6 +135,7 @@ decode_proceed(Recog *recog)
 
 #ifdef POWER_REJECT
   for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
+    if (!mfcc->valid) continue;
     if (mfcc->f == 0) {
       mfcc->avg_power = 0.0;
       if (debug2_flag) jlog("STAT: power_reject: reset\n");
@@ -143,7 +144,14 @@ decode_proceed(Recog *recog)
 #endif
 
 
+#ifdef GMM_VAD
   if (recog->gmm != NULL) {
+    /* reset flags */
+    break_gmm = FALSE;
+    recog->gc->want_rewind = FALSE;
+  }
+#endif
+  if (recog->gmm != NULL && recog->gmmmfcc->valid) {
     /* GMM ׻Ԥ */
     if (recog->gmmmfcc->f == 0) {
       /* GMM ׻ν */
@@ -152,11 +160,8 @@ decode_proceed(Recog *recog)
     /* Υե졼ФGMM٤׻ */
     gmm_proceed(recog);
 #ifdef GMM_VAD
-    /* reset break flag */
-    break_gmm = FALSE;
     /* Check for GMM-based VAD */
     gmm = recog->gc;
-    gmm->want_rewind = FALSE;
     gmm_check_trigger(recog);
     if (gmm->after_trigger) {
       /* after trigger, in speech area */
@@ -165,7 +170,7 @@ decode_proceed(Recog *recog)
 #ifdef GMM_VAD_DEBUG
 	printf("GMM_VAD: %d: down trigger\n", recog->gmmmfcc->f);
 #endif
-	recog->gmmmfcc->sparea_start = recog->gmmmfcc->f - recog->jconf->detect.gmm_margin;
+	recog->gmmmfcc->sparea_start = recog->gmmmfcc->f + 1 - recog->jconf->detect.gmm_margin;
 	if (recog->gmmmfcc->sparea_start < 0) recog->gmmmfcc->sparea_start = 0;
 	gmm->after_trigger = FALSE;
 	recog->gmmmfcc->segmented = TRUE;
@@ -179,10 +184,10 @@ decode_proceed(Recog *recog)
 	/* start recognition */
 	/* request caller to rewind to the backstep point and
 	   re-start with normal search */
-	if (recog->gmmmfcc->f < recog->jconf->detect.gmm_margin) {
+	if (recog->gmmmfcc->f + 1 < recog->jconf->detect.gmm_margin) {
 	  gmm->rewind_frame = 0;
 	} else {
-	  gmm->rewind_frame = recog->gmmmfcc->f - recog->jconf->detect.gmm_margin;
+	  gmm->rewind_frame = recog->gmmmfcc->f + 1 - recog->jconf->detect.gmm_margin;
 	}
 #ifdef GMM_VAD_DEBUG
 	printf("GMM_VAD: %d: up trigger, start recognition with %d frame rewind\n", recog->gmmmfcc->f, recog->gmmmfcc->f - gmm->rewind_frame);
@@ -196,10 +201,10 @@ decode_proceed(Recog *recog)
 
 	/* if noise goes more than a certain frame, shrink the noise area
 	   to avoid unlimited memory usage */
-	if (recog->gmmmfcc->f > GMM_VAD_AUTOSHRINK_LIMIT) {
+	if (recog->gmmmfcc->f + 1 > GMM_VAD_AUTOSHRINK_LIMIT) {
 	  gmm->want_rewind = TRUE;
 	  gmm->want_rewind_reprocess = FALSE;
-	  gmm->rewind_frame = recog->gmmmfcc->f - recog->jconf->detect.gmm_margin;
+	  gmm->rewind_frame = recog->gmmmfcc->f + 1 - recog->jconf->detect.gmm_margin;
 	  if (debug2_flag) {
 	    jlog("DEBUG: GMM_VAD: pause exceeded %d, rewind\n", GMM_VAD_AUTOSHRINK_LIMIT);
 	  }
@@ -256,7 +261,7 @@ decode_proceed(Recog *recog)
   break_flag = FALSE;
   if (break_decode
 #ifdef GMM_VAD
-      && (recog->gmm != NULL && break_gmm)
+      || (recog->gmm != NULL && recog->gmmmfcc->valid && break_gmm)
 #endif
       ) {
     break_flag = TRUE;
@@ -405,7 +410,7 @@ decode_end_segmented(Recog *recog)
   if (recog->jconf->decodeopt.segment) {
     finalize_segment(recog);
   }
-  if (recog->gmm != NULL) {
+  if (recog->gmm != NULL && recog->gmmmfcc->valid) {
     /* GMM ׻νλ */
     gmm_end(recog);
   }
@@ -452,7 +457,7 @@ decode_end(Recog *recog)
   for (mfcc = recog->mfcclist; mfcc; mfcc = mfcc->next) {
     mfcc->segmented = FALSE;
   }
-  if (recog->gmm != NULL) {
+  if (recog->gmm != NULL && recog->gmmmfcc->valid) {
     /* GMM ׻νλ */
     gmm_end(recog);
   }
