@@ -1,7 +1,5 @@
 /**
  * @file   adin_mic_linux_oss.c
- * @author Akinobu LEE
- * @date   Sun Feb 13 16:18:26 2005
  *
  * <JA>
  * @brief  ޥ (Linux/OSS)
@@ -50,13 +48,16 @@
  * environment variable AUDIODEV.
  * </EN>
  *
- * $Revision: 1.2 $
+ * @author Akinobu LEE
+ * @date   Sun Feb 13 16:18:26 2005
+ *
+ * $Revision: 1.3 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -78,12 +79,18 @@
 #define FREQALLOWRANGE 200	///< Acceptable width of sampling frequency
 #define MAXPOLLINTERVAL 300	///< Read timeout in msec.
 /**
- * Data fragment size.  Input will be delayed by 2^X bytes.
- * The default value of 10 means we treat input per a unit of 2~10=1024 bytes,
- * which corresponds to 32 msec in 16kHz sampling.
+ * Maximum Data fragment Length in msec.  Input can be delayed to this time.
+ * a maximum of 2^x number smaller than this value will be taken.
+ * You can override this value by specifying environment valuable
+ * "LATENCY_MSEC".
  * 
  */
-#define FRAGMENT_POWER 10
+#define MAX_FRAGMENT_MSEC 50
+/**
+ * Minimum fragment length in bytes
+ * 
+ */
+#define MIN_FRAGMENT_SIZE 256
 
 static int audio_fd;		///< Audio descriptor
 static boolean need_swap;	///< Whether samples need byte swap
@@ -105,23 +112,28 @@ adin_mic_standby(int sfreq, void *dummy)
   int samplerate;	/* 16kHz */
   char *defaultdev = DEFAULT_DEVICE; /* default device */
   char *devname;
+  int frag;
+  int frag_msec;
+  char *env;
 
   /* set device name */
   if ((devname = getenv("AUDIODEV")) == NULL) {
     devname = defaultdev;
+    jlog("Stat: adin_oss: device name = %s\n", devname);
+  } else {
+    jlog("Stat: adin_oss: device name obtained from AUDIODEV: %s\n", devname);
   }
 
   /* open device */
   if ((audio_fd = open(devname, O_RDONLY|O_NONBLOCK)) == -1) {
-    j_printerr("adin_mic_standby: device=%s\n", devname);
-    perror("adin_mic_standby: open device");
+    jlog("Error: adin_oss: failed to open %s\n", devname);
     return(FALSE);
   }
 
   /* check whether soundcard can record 16bit data */
   /* and set fmt */
   if (ioctl(audio_fd, SNDCTL_DSP_GETFMTS, &fmt_can) == -1) {
-    perror("adin_mic_standby: sndctl_dsp_getfmts");
+    jlog("Error: adin_oss: failed to get formats from audio device\n");
     return(FALSE);
   }
 #ifdef WORDS_BIGENDIAN
@@ -139,14 +151,14 @@ adin_mic_standby(int sfreq, void *dummy)
     fmt = fmt2;
     need_swap = TRUE;
   } else {
-    fprintf(stderr, "adin_mic_standby: 16bit recording not supported\n");
+    jlog("Error: adin_oss: 16bit recording not supported on this device\n");
     return FALSE;
   }
 #ifdef DEBUG
   if (need_swap) {
-    j_printf("samples need swap\n");
+    jlog("Stat: adin_oss: samples need swap\n");
   } else {
-    j_printf("samples need not swap\n");
+    jlog("Stat: adin_oss: samples need not swap\n");
   }
 #endif
   
@@ -155,8 +167,7 @@ adin_mic_standby(int sfreq, void *dummy)
   /* re-open for recording */
   /* open device */
   if ((audio_fd = open(devname, O_RDONLY)) == -1) {
-    j_printerr("adin_mic_standby: device=%s\n", devname);
-    perror("adin_mic_standby: open device");
+    jlog("Error: adin_oss: failed to open %s", devname);
     return(FALSE);
   }
 
@@ -165,20 +176,41 @@ adin_mic_standby(int sfreq, void *dummy)
   /* (and smaller fragment causes busy buffering) */
   {
     int arg;
-    arg = 0x7fff0000 | FRAGMENT_POWER;
+    int f, f2;
+
+    /* if environment variable "LATENCY_MSEC" is defined, try to set it
+       as a minimum latency in msec (will be rouneded to 2^x). */
+    if ((env = getenv("LATENCY_MSEC")) == NULL) {
+      frag_msec = MAX_FRAGMENT_MSEC;
+    } else {
+      frag_msec = atoi(env);
+    }
+      
+    /* get fragment size from MAX_FRAGMENT_MSEC and MIN_FRAGMENT_SIZE */
+    f = 0;
+    f2 = 1;
+    while (f2 * 1000 / (sfreq * sizeof(SP16)) <= frag_msec
+	   || f2 < MIN_FRAGMENT_SIZE) {
+      f++;
+      f2 *= 2;
+    }
+    frag = f - 1;
+
+    /* set to device */
+    arg = 0x7fff0000 | frag;
     if (ioctl(audio_fd, SNDCTL_DSP_SETFRAGMENT, &arg)) {
-      fprintf(stderr, "adin_mic_standby: set fragment size to 2^%d=%d bytes (%d msec)\n", FRAGMENT_POWER, 2 << (FRAGMENT_POWER-1), (2 << (FRAGMENT_POWER-1)) * 1000 / (sfreq * sizeof(SP16)));
+      jlog("Stat: adin_oss: set fragment size to 2^%d=%d bytes (%d msec)\n", frag, 2 << (frag-1), (2 << (frag-1)) * 1000 / (sfreq * sizeof(SP16)));
     }
   }
   
   /* set format, samplerate, channels */
   rfmt = fmt;
   if (ioctl(audio_fd, SNDCTL_DSP_SETFMT, &rfmt) == -1) {
-    perror("adin_mic_standby: sndctl_dsp_setfmt");
+    jlog("Error: adin_oss: failed to get available formats from device\n");
     return(FALSE);
   }
   if (rfmt != fmt) {
-    fprintf(stderr, "adin_mic_standby: 16bit recording not supported\n");
+    jlog("Error: adin_oss: 16bit recording is not supported on this device\n");
     return FALSE;
   }
 
@@ -191,13 +223,15 @@ adin_mic_standby(int sfreq, void *dummy)
     stereo = 0;			/* mono */
     if (ioctl(audio_fd, SNDCTL_DSP_STEREO, &stereo) == -1) {
       /* failed: SNDCTL_DSP_STEREO not supported */
-      perror("adin_mic_standby: sndctl_dsp_stereo (mono)");
+      jlog("Stat: adin_oss: sndctl_dsp_stereo not supported, going to try another...\n");
     } else {
       if (stereo != 0) {
 	/* failed to set monaural recording by SNDCTL_DSP_STEREO */
-	fprintf(stderr, "adin_mic_standby: failed to set monaural recording by SNDCTL_DSP_STEREO\n");
+	jlog("Stat: adin_oss: failed to set monaural recording by sndctl_dsp_stereo\n");
+	jlog("Stat: adin_oss: going to try another...\n");
       } else {
 	/* succeeded to set monaural recording by SNDCTL_DSP_STEREO */
+	//jlog("Stat: adin_oss: recording now set to mono\n");
 	stereo_rec = FALSE;
 	ok_p = TRUE;
       }
@@ -207,14 +241,15 @@ adin_mic_standby(int sfreq, void *dummy)
       channels = 1;
       if (ioctl(audio_fd, SNDCTL_DSP_CHANNELS, &channels) == -1) {
 	/* failed: SNDCTL_DSP_CHANNELS not supported */
-	perror("adin_mic_standby: sndctl_dsp_channels (channels = 1)");
+	jlog("Stat: adin_oss: sndctl_dsp_channels not supported, try another...\n");
       } else {
 	if (channels != 1) {
 	  /* failed to set monaural recording by SNDCTL_DSP_CHANNELS */
-	  fprintf(stderr, "adin_mic_standby: failed to set monaural recording by SNDCTL_DSP_CHANNELS\n");
+	  jlog("Stat: adin_oss: failed to set monaural recording by sndctl_dsp_channels\n");
+	  jlog("Stat: adin_oss: going to try another...\n");
 	} else {
 	  /* succeeded to set monaural recording by SNDCTL_DSP_CHANNELS */
-	  fprintf(stderr, "adin_mic_standby: SNDCTL_DSP_CHANNELS used for monaural record setting\n");
+	  //jlog("Stat: adin_oss: recording now set to mono\n");
 	  stereo_rec = FALSE;
 	  ok_p = TRUE;
 	}
@@ -222,17 +257,18 @@ adin_mic_standby(int sfreq, void *dummy)
     }
     if (! ok_p) {
       /* try using stereo input */
-      fprintf(stderr, "adin_mic_standby: monaural recording failed, use stereo left channel\n");
+      jlog("Warning: adin_oss: failed to setup monaural recording, trying to use the left channel of stereo input\n");
       stereo = 1;			/* stereo */
       if (ioctl(audio_fd, SNDCTL_DSP_STEREO, &stereo) == -1) {
 	/* failed: SNDCTL_DSP_STEREO not supported */
-	perror("adin_mic_standby: sndctl_dsp_stereo (stereo)");
+	jlog("Stat: adin_oss: failed to set stereo input using sndctl_dsp_stereo\n");
       } else {
 	if (stereo != 1) {
 	  /* failed to set stereo recording by SNDCTL_DSP_STEREO */
-	  fprintf(stderr, "adin_mic_standby: failed to set stereo recording by SNDCTL_DSP_STEREO\n");
+	  jlog("Stat: adin_oss: failed to set stereo input using sndctl_dsp_stereo\n");
 	} else {
 	  /* succeeded to set stereo recording by SNDCTL_DSP_STEREO */
+	  jlog("Stat: adin_oss: recording now set to stereo, using left channel\n");
 	  stereo_rec = TRUE;
 	  ok_p = TRUE;
 	}
@@ -243,48 +279,50 @@ adin_mic_standby(int sfreq, void *dummy)
       channels = 2;
       if (ioctl(audio_fd, SNDCTL_DSP_CHANNELS, &channels) == -1) {
 	/* failed: SNDCTL_DSP_CHANNELS not supported */
-	perror("adin_mic_standby: sndctl_dsp_channels (channels = 2)");
+	jlog("Stat: adin_oss: failed to set stereo input using sndctl_dsp_channels\n");
       } else {
 	if (channels != 2) {
 	  /* failed to set stereo recording by SNDCTL_DSP_CHANNELS */
-	  fprintf(stderr, "adin_mic_standby: failed to set stereo recording by SNDCTL_DSP_CHANNELS\n");
+	  jlog("Stat: adin_oss: failed to set stereo input using sndctl_dsp_channels\n");
 	} else {
 	  /* succeeded to set stereo recording by SNDCTL_DSP_CHANNELS */
-	  fprintf(stderr, "adin_mic_standby: SNDCTL_DSP_CHANNELS used for stereo record setting\n");
+	  jlog("Stat: adin_oss: recording now set to stereo, using left channel\n");
 	  stereo_rec = TRUE;
 	  ok_p = TRUE;
 	}
       }
     }
     if (! ok_p) {		/* all failed */
-      fprintf(stderr,"adin_mic_standby: give up setting record channels\n");
+      jlog("Error: adin_oss: failed to setup recording channels\n");
       return FALSE;
     }
   }
 
   samplerate = sfreq;
   if (ioctl(audio_fd, SNDCTL_DSP_SPEED, &samplerate) == -1) {
-    fprintf(stderr, "adin_mic_standby: sndctl_dsp_speed (%dHz)\n", sfreq);
+    jlog("Erorr: adin_oss: failed to set sample rate to %dHz\n", sfreq);
     return(FALSE);
   }
   if (samplerate < sfreq - FREQALLOWRANGE || samplerate > sfreq + FREQALLOWRANGE) {
-    fprintf(stderr,"adin_mic_standby: couldn't set sampling rate to near %dHz. (%d)\n", sfreq, samplerate);
+    jlog("Error: adin_oss: failed to set sampling rate to near %dHz. (%d)\n", sfreq, samplerate);
     return FALSE;
   }
   if (samplerate != sfreq) {
-    fprintf(stderr,"adin_mic_standby: set sampling rate to %dHz\n", samplerate);
+    jlog("Warning: adin_oss: specified sampling rate was %dHz but set to %dHz, \n", sfreq, samplerate);
   }
+  jlog("Stat: adin_oss: sampling rate = %dHz\n", samplerate);
 
   /* get actual fragment size */
   if (ioctl(audio_fd, SNDCTL_DSP_GETBLKSIZE, &frag_size) == -1) {
-    fprintf(stderr, "adin_mic_standby: failed to get fragment size\n");
+    jlog("Error: adin_oss: failed to get fragment size\n");
     return(FALSE);
   }
-  j_printf("fragment size = %d bytes (%d msec)", frag_size, frag_size * 1000/ (sfreq * sizeof(SP16)));
-  if (frag_size !=  2 << (FRAGMENT_POWER-1)) {
-    j_printf(" (tried = %d bytes)", 2 << (FRAGMENT_POWER-1));
+  if (env == NULL) {
+    jlog("Stat: adin_oss: going to set latency to %d msec\n", frag_msec);
+  } else {
+    jlog("Stat: adin_oss: going to set latency to %d msec (from env LATENCY_MSEC)\n", frag_msec);
   }
-  j_printf("\n");
+  jlog("Stat: adin_oss: audio I/O Latency = %d msec (fragment size = %d samples)\n", frag_size * 1000/ (sfreq * sizeof(SP16)), frag_size / sizeof(SP16));
 
   return TRUE;
 }
@@ -295,7 +333,7 @@ adin_mic_standby(int sfreq, void *dummy)
  * @return TRUE on success, FALSE on failure.
  */
 boolean
-adin_mic_start()
+adin_mic_begin()
 {
   char buf[4];
   /* Read 1 sample (and ignore it) to tell the audio device start recording.
@@ -305,7 +343,6 @@ adin_mic_start()
   } else {
     read(audio_fd, buf, 2);
   }
-
   return(TRUE);
 }
 
@@ -315,7 +352,7 @@ adin_mic_start()
  * @return TRUE on success, FALSE on failure.
  */
 boolean
-adin_mic_stop()
+adin_mic_end()
 {
   /*
    * Not reset device on each end of speech, just let the buffer overrun...
@@ -363,13 +400,13 @@ adin_mic_read(SP16 *buf, int sampnum)
   status = select(audio_fd+1, &rfds, NULL, NULL, &tv);
   if (status < 0) {
     /* select() failed */
-    j_printerr("adin_mic_read: device polling failed\n");
+    jlog("Error: adin_oss: failed to poll device\n");
     return(-2);			/* error */
   }
   if (FD_ISSET(audio_fd, &rfds)) { /* has some data */
     /* get sample num that can be read without blocking */
     if (ioctl(audio_fd, SNDCTL_DSP_GETISPACE, &info) == -1) {
-      perror("adin_mic_read: sndctl_dsp_getispace");
+      jlog("Error: adin_oss: failed to get number of samples in the buffer\n");
       return(-2);
     }
     /* get them as much as possible */
@@ -379,7 +416,7 @@ adin_mic_read(SP16 *buf, int sampnum)
     size &= ~ 1;		/* Force 16bit alignment */
     cnt = read(audio_fd, buf, size);
     if ( cnt < 0 ) {
-      perror("adin_mic_read: read error\n");
+      jlog("Error: adin_oss: failed to read samples\n");
       return ( -2 );
     }
     cnt /= sizeof(short);
@@ -392,7 +429,7 @@ adin_mic_read(SP16 *buf, int sampnum)
     
     if (need_swap) swap_sample_bytes(buf, cnt);
   } else {			/* no data after waiting */
-    j_printerr("adin_mic_read: no data fragment after %d msec?\n", MAXPOLLINTERVAL);
+    jlog("Warning: adin_oss: no data fragment after %d msec?\n", MAXPOLLINTERVAL);
     cnt = 0;
   }
 
