@@ -1,7 +1,5 @@
 /**
  * @file   dfa_lookup.c
- * @author Akinobu LEE
- * @date   Tue Feb 15 14:11:41 2005
  * 
  * <JA>
  * @brief  ñ켭ñб륫ƥֹ֤
@@ -17,13 +15,16 @@
  * compiler mkdfa.pl.  This function only checks the value.
  * </EN>
  * 
+ * @author Akinobu LEE
+ * @date   Tue Feb 15 14:11:41 2005
+ *
  * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -51,7 +52,7 @@ dfa_symbol_lookup(DFA_INFO *dinfo, char *terminalname)
   for(p=terminalname;*p!='\0';p++) {
     c = *p;
     if (! isdigit(c)) {
-      j_printerr("Error: wrong format: terminal number is not digit in dict! [%s]\n", terminalname);
+      jlog("Error: dfa_lookup: terminal number is not digit in dict! [%s]\n", terminalname);
       return(WORD_INVALID);
     }
   }
