@@ -1,7 +1,5 @@
 /**
  * @file   rddfa.c
- * @author Akinobu LEE
- * @date   Tue Feb 15 14:54:40 2005
  * 
  * <JA>
  * @brief  DFAʸˡɤ߹
@@ -11,13 +9,16 @@
  * @brief  Read DFA grammar from a file
  * </EN>
  * 
- * $Revision: 1.4 $
+ * @author Akinobu LEE
+ * @date   Tue Feb 15 14:54:40 2005
+ *
+ * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -174,13 +175,30 @@ rddfa_line(char *line, DFA_INFO *dinfo, int *state_max, int *arc_num, int *termi
   DFA_ARC *newarc;
   int state, terminal, next_state;
   unsigned int status;
+  char *p;
 
   if (strmatch(buf, "DFAEND")) return(FALSE);
   /* format: state terminalID nextstate statuscode_of_state */
-  state = atoi(first_token(line));
-  terminal = atoi(next_token());
-  next_state = atoi(next_token());
-  sscanf(next_token(), "%x", &status);
+  if ((p = strtok(line, DELM)) == NULL) {
+    jlog("Error: rddfa: failed to parse, corrupted or invalid data?\n");
+    return FALSE;
+  }
+  state = atoi(p);
+  if ((p = strtok(NULL, DELM)) == NULL) {
+    jlog("Error: rddfa: failed to parse, corrupted or invalid data?\n");
+    return FALSE;
+  }
+  terminal = atoi(p);
+  if ((p = strtok(NULL, DELM)) == NULL) {
+    jlog("Error: rddfa: failed to parse, corrupted or invalid data?\n");
+    return FALSE;
+  }
+  next_state = atoi(p);
+  if ((p = strtok(NULL, DELM)) == NULL) {
+    jlog("Error: rddfa: failed to parse, corrupted or invalid data?\n");
+    return FALSE;
+  }
+  sscanf(p, "%x", &status);
 
   if (state >= dinfo->maxstatenum) {      /* expand */
     dfa_state_expand(dinfo, state+1);
@@ -206,9 +224,9 @@ rddfa_line(char *line, DFA_INFO *dinfo, int *state_max, int *arc_num, int *termi
     newarc->to_state = next_state;
     newarc->next     = dinfo->st[state].arc;
     dinfo->st[state].arc = newarc;
+    (*arc_num)++;
   }
 
-  (*arc_num)++;
   if (*state_max < state) *state_max = state;
   if (*terminal_max < terminal) *terminal_max = terminal;
 
