@@ -1,7 +1,5 @@
 /**
  * @file   check_hmmtype.c
- * @author Akinobu LEE
- * @date   Tue Feb 15 19:11:50 2005
  * 
  * <JA>
  * @brief  %HMM ħեΥѥ᡼å
@@ -11,13 +9,16 @@
  * @brief  Check the parameter types between %HMM and input
  * </EN>
  * 
- * $Revision: 1.3 $
+ * @author Akinobu LEE
+ * @date   Tue Feb 15 19:11:50 2005
+ *
+ * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -39,15 +40,15 @@ check_hmm_options(HTK_HMM_INFO *hmm)
   boolean ret_flag = TRUE;
   
   if (hmm->opt.stream_info.num > 1) {
-    j_printerr("ERROR: Input stream must be single\n");
+    jlog("Error: check_hmmtype: Input stream must be single\n");
     ret_flag = FALSE;
   }
   if (hmm->opt.dur_type != D_NULL) {
-    j_printerr("ERROR: Duration types other than NULLD are not supported.\n");
+    jlog("Error: check_hmmtype: Duration types other than NULLD are not supported.\n");
     ret_flag = FALSE;
   }
   if (hmm->opt.cov_type != C_DIAG_C) {
-    j_printerr("ERROR: Covariance matrix type must be DIAGC, others not supported.\n");
+    jlog("Error: check_hmmtype: Covariance matrix type must be DIAGC, others not supported.\n");
     ret_flag = FALSE;
   }
 
@@ -73,9 +74,9 @@ check_param_coherence(HTK_HMM_INFO *hmm, HTK_Param *pinfo)
   if (hmm->opt.param_type
       != (pinfo->header.samptype & ~(F_COMPRESS | F_CHECKSUM))) {
 /* 
- *     j_printerr("ERROR: incompatible parameter type\n");
- *     j_printf("HMM trained by %s\n", param_code2str(buf, hmm->opt.param_type, FALSE));
- *     j_printf("input parameter is %s\n", param_code2str(buf, pinfo->header.samptype, FALSE));
+ *     jlog("Error: check_hmmtype: incompatible parameter type\n");
+ *     jlog("Error: check_hmmtype: HMM trained by %s\n", param_code2str(buf, hmm->opt.param_type, FALSE));
+ *     jlog("Error: check_hmmtype: input parameter is %s\n", param_code2str(buf, pinfo->header.samptype, FALSE));
  */
     ret_flag = FALSE;
   }
@@ -83,8 +84,8 @@ check_param_coherence(HTK_HMM_INFO *hmm, HTK_Param *pinfo)
   /* vector length check */
   if (hmm->opt.vec_size != pinfo->veclen) {
 /* 
- *     j_printerr("ERROR: vector length differ.\n");
- *     j_printerr("HMM=%d, param=%d\n", hmm->opt.vec_size, pinfo->veclen);
+ *     jlog("Error: check_hmmtype: vector length differ.\n");
+ *     jlog("Error: check_hmmtype: HMM=%d, param=%d\n", hmm->opt.vec_size, pinfo->veclen);
  */
     ret_flag = FALSE;
   }
