@@ -1,7 +1,5 @@
 /**
  * @file   rdhmmdef_data.c
- * @author Akinobu LEE
- * @date   Wed Feb 16 01:12:19 2005
  * 
  * <JA>
  * @brief  HTK %HMM եɤ߹ߡ%HMM ǥ
@@ -11,13 +9,16 @@
  * @brief  Read HTK %HMM definition file: %HMM model
  * </EN>
  * 
- * $Revision: 1.4 $
+ * @author Akinobu LEE
+ * @date   Wed Feb 16 01:12:19 2005
+ *
+ * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
@@ -63,16 +64,16 @@ htk_hmmdata_add(HTK_HMM_INFO *hmm, HTK_HMM_Data *new)
 
   if (new->name == NULL) {
     /* HMM must have a name */
-    rderr("Error: HMM has no name");
+    rderr("HMM has no name");
   } else {
     /* add index to search index tree */
     if (hmm->physical_root == NULL) {
       hmm->physical_root = aptree_make_root_node(new);
     } else {
       match = aptree_search_data(new->name, hmm->physical_root);
-      if (strmatch(match->name, new->name)) {
+      if (match != NULL && strmatch(match->name, new->name)) {
 	/* HMM of the same name should not be defined */
-	j_printerr("Error: HMM \"%s\" is defined more than twice\n", new->name);
+	jlog("Error: rdhmmdef_data: HMM \"%s\" is defined more than twice\n", new->name);
 	rderr(NULL);
       } else {
 	aptree_add_entry(new->name, new, match->name, &(hmm->physical_root));
