@@ -20,7 +20,7 @@
  * @author Akinobu LEE
  * @date   Wed Feb 16 16:52:24 2005
  *
- * $Revision: 1.4 $
+ * $Revision: 1.6 $
  * 
  */
 /*
@@ -30,7 +30,7 @@
  * All rights reserved
  */
 
-/* $Id: ngram_read_arpa.c,v 1.4 2007/12/18 08:45:54 sumomo Exp $ */
+/* $Id: ngram_read_arpa.c,v 1.6 2008/01/30 00:48:13 sumomo Exp $ */
 
 /* words should be alphabetically sorted */
 
@@ -595,7 +595,7 @@ ngram_read_arpa(FILE *fp, NGRAM_INFO *ndata, boolean addition)
 	/* for 3-gram and later 24 bit mode is preferred,
 	   but should be disabled if number of entries is over 2^24 */
 	if (ndata->d[i].totalnum >= NNIDMAX) {
-	  jlog("Warning: ngram_read_arpa: more than 24bit %d-gram tuples, use 32bit index\n", NNIDMAX, n+1);
+	  jlog("Warning: ngram_read_arpa: num of %d-gram exceeds 24bit, now switch to 32bit index\n", i+1);
 	  ndata->d[i].is24bit = FALSE;
 	} else {
 	  ndata->d[i].is24bit = TRUE;
@@ -635,11 +635,10 @@ ngram_read_arpa(FILE *fp, NGRAM_INFO *ndata, boolean addition)
 
     ndata->n = n;
 
-    for(i=1;i<n;i++) {
-      if (ndata->d[i].bo_wt != NULL) {
+    for(i=2;i<n;i++) {
+      if (ndata->d[i-1].bo_wt != NULL) {
 	/* perform back-off compaction */
-	if (ngram_compact_context(ndata, i+1) == FALSE) return FALSE;
-	ndata->d[i].ct_compaction = TRUE;
+	if (ngram_compact_context(ndata, i) == FALSE) return FALSE;
       }
     }
     
