@@ -1,7 +1,5 @@
 /**
  * @file   ptree.c
- * @author Akinobu LEE
- * @date   Thu Feb 17 15:34:39 2005
  * 
  * <JA>
  * @brief  ѥȥꥷڤѤ̾ǡ int ξ
@@ -11,19 +9,25 @@
  * @brief  Patricia index tree for name lookup: data type = int
  * </EN>
  * 
- * $Revision: 1.3 $
+ * @author Akinobu LEE
+ * @date   Thu Feb 17 15:34:39 2005
+ *
+ * $Revision: 1.2 $
  * 
  */
 /*
- * Copyright (c) 1991-2006 Kawahara Lab., Kyoto University
+ * Copyright (c) 1991-2007 Kawahara Lab., Kyoto University
  * Copyright (c) 2000-2005 Shikano Lab., Nara Institute of Science and Technology
- * Copyright (c) 2005-2006 Julius project team, Nagoya Institute of Technology
+ * Copyright (c) 2005-2007 Julius project team, Nagoya Institute of Technology
  * All rights reserved
  */
 
 #include <sent/stddefs.h>
 #include <sent/ptree.h>
 
+static unsigned char mbit[] = {0x80, 0x40, 0x20, 0x10, 0x08, 0x04, 0x02, 0x01};
+  
+
 /** 
  * String bit test function.
  * 
@@ -36,17 +40,25 @@ int
 testbit(char *str, int bitplace)
 {
   int maskptr;
-  int bitshift;
-  unsigned char maskbit;
   
-  maskptr = bitplace / 8;
-  if ((bitshift = bitplace % 8) != 0) {
-    maskbit = 0x80 >> bitshift;
-  } else {
-    maskbit = 0x80;
-  }
-  if (strlen(str)<maskptr) return 0;
-  return(str[maskptr] & maskbit);
+  if ((maskptr = bitplace >> 3) > strlen(str)) return 0;
+  return(str[maskptr] & mbit[bitplace & 7]);
+}
+
+/** 
+ * Local bit test function for search.
+ * 
+ * @param str [in] key string
+ * @param bitplace [in] bit place to test.
+ * @param maxbitplace [in] maximum number of bitplace
+ * 
+ * @return the content of tested bit in @a tmp_str, either 0 or 1.
+ */
+int
+testbit_max(char *str, int bitplace, int maxbitplace)
+{
+  if (bitplace >= maxbitplace) return 0;
+  return(str[bitplace >> 3] & mbit[bitplace & 7]);
 }
 
 /** 
@@ -71,7 +83,6 @@ where_the_bit_differ(char *str1, char *str2)
   return(bitloc);
 }
 
-
 /** 
  * Allocate a new node.
  * 
@@ -110,12 +121,12 @@ make_ptree(char **words, int *data, int wordsnum, int bitplace)
   PATNODE *ntmp;
 
 #if 0
-  j_printf("%d:", wordsnum);
+  printf("%d:", wordsnum);
   for (i=0;i<wordsnum;i++) {
-    j_printf(" %s",words[i]);
+    printf(" %s",words[i]);
   }
-  j_printf("\n");
-  j_printf("test bit = %d\n", bitplace);
+  printf("\n");
+  printf("test bit = %d\n", bitplace);
 #endif
 
   if (wordsnum == 1) {
@@ -170,12 +181,12 @@ disp_ptree(PATNODE *node, int level)
   int i;
 
   for (i=0;i<level;i++) {
-    j_printf("-");
+    printf("-");
   }
   if (node->left0 == NULL && node->right1 == NULL) {
-    j_printf("LEAF:%d\n", node->value.data);
+    printf("LEAF:%d\n", node->value.data);
   } else {
-    j_printf("%d\n", node->value.thres_bit);
+    printf("%d\n", node->value.thres_bit);
     if (node->left0 != NULL) {
       disp_ptree(node->left0, level+1);
     }
@@ -185,51 +196,25 @@ disp_ptree(PATNODE *node, int level)
   }
 }
 
-/* temporary work area for search */
-static char *tmp_str;		///< Local work area: current string we are searching for
-static int maxbitplace;		///< Local work area: Maximum bit length of @a tmp_str
-
-/** 
- * Local bit test function for search.
- * 
- * @param bitplace [in] bit place to test.
- * 
- * @return the content of tested bit in @a tmp_str, either 0 or 1.
- */
-static int
-testbit_local(int bitplace)
-{
-  int maskptr;
-  int bitshift;
-  unsigned char maskbit;
-
-  if (bitplace >= maxbitplace) return 0;
-  maskptr = bitplace / 8;
-  if ((bitshift = bitplace % 8) != 0) {
-    maskbit = 0x80 >> bitshift;
-  } else {
-    maskbit = 0x80;
-  }
-  return(tmp_str[maskptr] & maskbit);
-}
-
 /** 
  * Recursive function to search the data in the tree
  * 
  * @param node [in] current node.
+ * @param str [in] key string
+ * @param maxbitplace [in] maximum number of bitplace
  * 
  * @return the found integer value.
  */
 static int
-ptree_search_data_r(PATNODE *node)
+ptree_search_data_r(PATNODE *node, char *str, int maxbitplace)
 {
   if (node->left0 == NULL && node->right1 == NULL) {
     return(node->value.data);
   } else {
-    if (testbit_local(node->value.thres_bit) != 0) {
-      return(ptree_search_data_r(node->right1));
+    if (testbit_max(str, node->value.thres_bit, maxbitplace) != 0) {
+      return(ptree_search_data_r(node->right1, str, maxbitplace));
     } else {
-      return(ptree_search_data_r(node->left0));
+      return(ptree_search_data_r(node->left0, str, maxbitplace));
     }
   }
 }
@@ -246,11 +231,10 @@ int
 ptree_search_data(char *str, PATNODE *node)
 {
   if (node == NULL) {
-    j_error("Error: ptree_search_data: no node, search for \"%s\" failed\n", str);
+    //("Error: ptree_search_data: no node, search for \"%s\" failed\n", str);
+    return -1;
   }
-  tmp_str = str;
-  maxbitplace = strlen(str) * 8 + 8;
-  return(ptree_search_data_r(node));
+  return(ptree_search_data_r(node, str, strlen(str) * 8 + 8));
 }
 
 
@@ -344,6 +328,7 @@ ptree_add_entry(char *str, int data, char *matchstr, PATNODE **rootnode)
 void
 free_ptree(PATNODE *node)
 {
+  if (node == NULL) return;
   if (node->left0 != NULL) free_ptree(node->left0);
   if (node->right1 != NULL) free_ptree(node->right1);
   free(node);
